Welcome to the Mistral documentation!
=====================================

Mistral is the OpenStack workflow service. This project aims to provide
a mechanism to define tasks and workflows without writing code, manage
and execute them in the cloud environment.

A workflow visualization tool is available via
`CloudFlow <https://github.com/nokia/CloudFlow>`_ and will help you debug
workflow executions, identify execution paths, explore task run times,
easily access input/output values and so many more...

Overview
--------

.. toctree::
    :maxdepth: 1

    overview
    quickstart
    architecture
    terminology/index
    main_features
    cookbooks

User guide
----------

**Installation**

.. toctree::
   :maxdepth: 2

   install/index
   configuration/index

**API**

.. toctree::
   :maxdepth: 2

   api/index

**Mistral Workflow Language**

.. toctree::
   :maxdepth: 2

   user/wf_lang_v2

**CLI**

.. toctree::
   :maxdepth: 1

   cli/index

Developer guide
---------------

.. toctree::
   :maxdepth: 2

   contributor/index

Admin guide
-----------

.. toctree::
   :maxdepth: 2

   admin/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
